@@ -4,10 +4,12 @@
 import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
+from PyQt4.QtGui import *
+from PyQt4.QtCore import *
 import Image
-import code
+#import code
 
-CURRENTVERSION = "0.3-0"
+CURRENTVERSION = "0.3-2"
 
 class MainWindow(QtGui.QMainWindow):
     def __init__(self):
@@ -23,31 +25,32 @@ class MainWindow(QtGui.QMainWindow):
         
         #Open Image
         self.ChargerScene()
+        
+        #Fullscreen Button        
+        fs = QtGui.QPushButton('', self)
+        fs.setGeometry(750, 0, 60, 48)
+        self.connect(fs, QtCore.SIGNAL('clicked()'), self.fullscreen)
+        
+        fsicon = QIcon("/opt/ltm/images/general_fullsize.png")
+        fs.setIcon(fsicon)
 
         ################
         #Menu Bar#
         ################
-        #Fullscreen
-        fullsc = QtGui.QAction('Fullscreen', self)
-        fullsc.setShortcut('Ctrl+X')
-        self.connect(fullsc, QtCore.SIGNAL('triggered()'), self.fullscreen)
-        
+
         #About
         abt = QtGui.QAction('About', self)
-        fullsc.setShortcut('Ctrl+A')
+        abt.setShortcut('Ctrl+A')
         self.connect(abt, QtCore.SIGNAL('triggered()'), self.showAbout)
 
-        
         #Connect to Menu Bar
         menubar = self.menuBar()
         file = menubar.addMenu('&Fichier')
-        file.addAction(fullsc)
         file.addAction(abt)
         
-        
         #About page
     def showAbout(self):
-        aboutString = "London Tube Map: v" + CURRENTVERSION + "\nAmir Bendjazia (benjezzy@gmail.com)\nMaemo Forums: El Amir, \nTwitter: benjezzy \nMany thanks to everyone who helped! "
+        aboutString = "London Tube Map: v" + CURRENTVERSION + "\nAmir B (benjezzy@gmail.com)\nMaemo Forums: El Amir \nTwitter: @benjezzy \nMany thanks to everyone who helped! "
         QtGui.QMessageBox.information(self, "About LTM: London Tube Map", aboutString)
         
     def fullscreen(self):
